@@ -120,6 +120,8 @@ void KDirModelTest::cleanupTestCase()
     m_tempDir = nullptr;
     delete m_dirModel;
     m_dirModel = nullptr;
+    delete m_dirModelForExpand;
+    m_dirModelForExpand = nullptr;
 }
 
 void KDirModelTest::fillModel(bool reload, bool expectAllIndexes)
@@ -1012,7 +1014,7 @@ void KDirModelTest::testUrlWithRef() // #171117
     KDirLister *dirLister = m_dirModel->dirLister();
     QUrl url = QUrl::fromLocalFile(path);
     url.setFragment(QStringLiteral("ref"));
-    QVERIFY(url.url().endsWith("#ref"));
+    QVERIFY(url.url().endsWith(QLatin1String("#ref")));
     dirLister->openUrl(url, KDirLister::NoFlags);
     checkedConnect(dirLister, SIGNAL(completed()), this, SLOT(slotListingCompleted()));
     enterLoop();
@@ -1022,19 +1024,7 @@ void KDirModelTest::testUrlWithRef() // #171117
     disconnect(dirLister, SIGNAL(completed()), this, SLOT(slotListingCompleted()));
 }
 
-void KDirModelTest::testFontUrlWithHost() // #160057
-{
-    if (!KProtocolInfo::isKnownProtocol(QStringLiteral("fonts"))) {
-        QSKIP("kio_fonts not installed");
-    }
-    QUrl url(QStringLiteral("fonts://foo/System"));
-    KDirLister *dirLister = m_dirModel->dirLister();
-    dirLister->openUrl(url, KDirLister::NoFlags);
-    checkedConnect(dirLister, SIGNAL(completed()), this, SLOT(slotListingCompleted()));
-    enterLoop();
-
-    QCOMPARE(dirLister->url().toString(), QString("fonts:/System"));
-}
+//void KDirModelTest::testFontUrlWithHost() // #160057 --> moved to kio_fonts (kfontinst/kio/autotests)
 
 void KDirModelTest::testRemoteUrlWithHost() // #178416
 {
@@ -1138,6 +1128,7 @@ void KDirModelTest::testMimeData()
     QVERIFY(mimeData->hasUrls());
     const QList<QUrl> urls = mimeData->urls();
     QCOMPARE(urls.count(), indexes.count());
+    delete mimeData;
 }
 
 void KDirModelTest::testDotHiddenFile_data()
@@ -1281,10 +1272,23 @@ void KDirModelTest::testOverwriteFileWithDir() // #151851 c4
     const QString file = path + "toplevelfile_1";
     const int oldTopLevelRowCount = m_dirModel->rowCount();
 
-    QSignalSpy spyRowsRemoved(m_dirModel, SIGNAL(rowsRemoved(QModelIndex,int,int)));
+    bool removalWithinTopLevel = false;
+    bool dataChangedAtFirstLevel = false;
+    auto rrc = connect(m_dirModel, &KDirModel::rowsRemoved, this, [&removalWithinTopLevel](const QModelIndex &index) {
+        if (!index.isValid()) {
+            // yes, that's what we have been waiting for
+            removalWithinTopLevel = true;
+        }
+    });
+    auto dcc = connect(m_dirModel, &KDirModel::dataChanged, this, [&dataChangedAtFirstLevel](const QModelIndex &index) {
+        if (index.isValid() && !index.parent().isValid()) {
+            // a change of a node whose parent is root, yay, that's it
+            dataChangedAtFirstLevel = true;
+        }
+    });
+
     checkedConnect(m_dirModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
                    &m_eventLoop, SLOT(exitLoop()));
-    QSignalSpy spyDataChanged(m_dirModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)));
 
     KIO::Job *job = KIO::move(QUrl::fromLocalFile(dir), QUrl::fromLocalFile(file), KIO::HideProgressInfo);
     job->setUiDelegate(nullptr);
@@ -1297,30 +1301,18 @@ void KDirModelTest::testOverwriteFileWithDir() // #151851 c4
 
     // Wait for a removal within the top level (that's for the old file going away), and also
     // for a dataChanged which notifies us that a file has become a directory
-    bool removalWithinTopLevel = false;
-    bool dataChangedAtFirstLevel = false;
+
     int retries = 0;
     while ((!removalWithinTopLevel || !dataChangedAtFirstLevel) && retries < 100) {
-        for (int i = 0; i < spyRowsRemoved.size() && !removalWithinTopLevel; ++i) {
-            QModelIndex parent = spyRowsRemoved[i][0].value<QModelIndex>();
-            if (!parent.isValid()) {
-                // yes, that's what we have been waiting for
-                removalWithinTopLevel = true;
-            }
-        }
-        for (int i = 0; i < spyDataChanged.size() && !dataChangedAtFirstLevel; ++i) {
-            QModelIndex idx = spyDataChanged[i][0].value<QModelIndex>();
-            if (idx.isValid() && !idx.parent().isValid()) {
-                // a change of a node whose parent is root, yay, that's it
-                dataChangedAtFirstLevel = true;
-            }
-        }
         QTest::qWait(10);
         ++retries;
     }
     QVERIFY(removalWithinTopLevel);
     QVERIFY(dataChangedAtFirstLevel);
 
+    m_dirModel->disconnect(rrc);
+    m_dirModel->disconnect(dcc);
+
     // If we come here, then rowsRemoved() was emitted - all good.
     const int topLevelRowCount = m_dirModel->rowCount();
     QCOMPARE(topLevelRowCount, oldTopLevelRowCount - 1); // one less than before
