@@ -49,12 +49,11 @@
 #ifdef Q_OS_UNIX
 #include <utime.h>
 #endif
-#include <assert.h>
 
 #include <qtemporaryfile.h>
-#include <QtCore/QTimer>
-#include <QtCore/QFile>
-#include <QtCore/QFileInfo>
+#include <QTimer>
+#include <QFile>
+#include <QFileInfo>
 #include <QLinkedList>
 #include <sys/stat.h> // mode_t
 #include <QPointer>
@@ -370,7 +369,7 @@ void CopyJobPrivate::slotResultStating(KJob *job)
             // We'll assume a file, and try to download anyway.
             qCDebug(KIO_COPYJOB_DEBUG) << "Error while stating source. Activating hack";
             q->removeSubjob(job);
-            assert(!q->hasSubjobs());    // We should have only one job at a time ...
+            Q_ASSERT(!q->hasSubjobs());    // We should have only one job at a time ...
             struct CopyInfo info;
             info.permissions = (mode_t) - 1;
             info.size = (KIO::filesize_t) - 1;
@@ -444,7 +443,7 @@ void CopyJobPrivate::slotResultStating(KJob *job)
         }
 
         q->removeSubjob(job);
-        assert(!q->hasSubjobs());
+        Q_ASSERT(!q->hasSubjobs());
 
         // After knowing what the dest is, we can start stat'ing the first src.
         statCurrentSrc();
@@ -576,9 +575,7 @@ void CopyJobPrivate::slotReport()
     case STATE_RENAMING:
         q->setTotalAmount(KJob::Files, m_srcList.count());
     // fall-through intended
-#if QT_VERSION >= QT_VERSION_CHECK(5,8,0)
         Q_FALLTHROUGH();
-#endif
     case STATE_COPYING_FILES:
         q->setProcessedAmount(KJob::Files, m_processedFiles);
         if (m_bURLDirty) {
@@ -654,7 +651,8 @@ void CopyJobPrivate::addCopyInfoFromUDSEntry(const UDSEntry &entry, const QUrl &
     info.permissions = entry.numberValue(KIO::UDSEntry::UDS_ACCESS, -1);
     info.mtime = QDateTime::fromMSecsSinceEpoch(1000 * entry.numberValue(KIO::UDSEntry::UDS_MODIFICATION_TIME, -1));
     info.ctime = QDateTime::fromMSecsSinceEpoch(1000 * entry.numberValue(KIO::UDSEntry::UDS_CREATION_TIME, -1));
-    info.size = (KIO::filesize_t) entry.numberValue(KIO::UDSEntry::UDS_SIZE, -1);
+    info.size = static_cast<KIO::filesize_t>(entry.numberValue(KIO::UDSEntry::UDS_SIZE, -1));
+
     if (info.size != (KIO::filesize_t) - 1) {
         m_totalSize += info.size;
     }
@@ -886,7 +884,13 @@ void CopyJobPrivate::statCurrentSrc()
         slotReport();
 
         qCDebug(KIO_COPYJOB_DEBUG)<<"Stating finished. To copy:"<<m_totalSize<<", available:"<<m_freeSpace;
-        //TODO warn user beforehand if space is not enough
+
+        if (m_totalSize > m_freeSpace && m_freeSpace != static_cast<KIO::filesize_t>(-1)) {
+            q->setError(ERR_DISK_FULL);
+            q->setErrorText(m_currentSrcURL.toDisplayString());
+            q->emitResult();
+            return;
+        }
 
         if (!dirs.isEmpty()) {
             emit q->aboutToCreate(q, dirs);
@@ -1091,7 +1095,7 @@ void CopyJobPrivate::slotResultCreatingDirs(KJob *job)
 
                         Q_ASSERT(((SimpleJob *)job)->url() == (*it).uDest);
                         q->removeSubjob(job);
-                        assert(!q->hasSubjobs());  // We should have only one job at a time ...
+                        Q_ASSERT(!q->hasSubjobs());  // We should have only one job at a time ...
 
                         // We need to stat the existing dir, to get its last-modification time
                         QUrl existingDest((*it).uDest);
@@ -1119,7 +1123,7 @@ void CopyJobPrivate::slotResultCreatingDirs(KJob *job)
     m_processedDirs++;
     //emit processedAmount( this, KJob::Directories, m_processedDirs );
     q->removeSubjob(job);
-    assert(!q->hasSubjobs());   // We should have only one job at a time ...
+    Q_ASSERT(!q->hasSubjobs());   // We should have only one job at a time ...
     createNextDir();
 }
 
@@ -1141,7 +1145,7 @@ void CopyJobPrivate::slotResultConflictCreatingDirs(KJob *job)
     const QString linkDest = entry.stringValue(KIO::UDSEntry::UDS_LINK_DEST);
 
     q->removeSubjob(job);
-    assert(!q->hasSubjobs());    // We should have only one job at a time ...
+    Q_ASSERT(!q->hasSubjobs());    // We should have only one job at a time ...
 
     // Always multi and skip (since there are files after that)
     RenameDialog_Options options(RenameDialog_MultipleItems | RenameDialog_Skip | RenameDialog_IsDirectory);
@@ -1211,7 +1215,7 @@ void CopyJobPrivate::slotResultConflictCreatingDirs(KJob *job)
         m_processedDirs++;
         break;
     default:
-        assert(0);
+        Q_ASSERT(0);
     }
     state = STATE_CREATING_DIRS;
     //emit processedAmount( this, KJob::Directories, m_processedDirs );
@@ -1304,7 +1308,7 @@ void CopyJobPrivate::slotResultCopyingFiles(KJob *job)
                     }
 
                     q->removeSubjob(job);
-                    assert(!q->hasSubjobs());
+                    Q_ASSERT(!q->hasSubjobs());
                     // We need to stat the existing file, to get its last-modification time
                     QUrl existingFile((*it).uDest);
                     SimpleJob *newJob = KIO::stat(existingFile, StatJob::DestinationSide, 2, KIO::HideProgressInfo);
@@ -1338,7 +1342,7 @@ void CopyJobPrivate::slotResultCopyingFiles(KJob *job)
                 && !qobject_cast<KIO::DeleteJob *>(job)   // Deleting source not already done
            ) {
             q->removeSubjob(job);
-            assert(!q->hasSubjobs());
+            Q_ASSERT(!q->hasSubjobs());
             // The only problem with this trick is that the error handling for this del operation
             // is not going to be right... see 'Very special case' above.
             KIO::Job *newjob = KIO::del((*it).uSource, HideProgressInfo);
@@ -1381,7 +1385,7 @@ void CopyJobPrivate::slotResultCopyingFiles(KJob *job)
     Q_ASSERT(kiojob);
     m_incomingMetaData += kiojob->metaData();
     q->removeSubjob(job);
-    assert(!q->hasSubjobs());   // We should have only one job at a time ...
+    Q_ASSERT(!q->hasSubjobs());   // We should have only one job at a time ...
     copyNextFile();
 }
 
@@ -1461,7 +1465,7 @@ void CopyJobPrivate::slotResultErrorCopyingFiles(KJob *job)
     }
 
     q->removeSubjob(job);
-    assert(!q->hasSubjobs());
+    Q_ASSERT(!q->hasSubjobs());
     switch (res) {
     case Result_Cancel:
         q->setError(ERR_USER_CANCELED);
@@ -1470,6 +1474,7 @@ void CopyJobPrivate::slotResultErrorCopyingFiles(KJob *job)
     case Result_AutoRename:
         m_bAutoRenameFiles = true;
     // fall through
+        Q_FALLTHROUGH();
     case Result_Rename: {
         QUrl newUrl((*it).uDest);
         newUrl.setPath(newPath);
@@ -1484,6 +1489,7 @@ void CopyJobPrivate::slotResultErrorCopyingFiles(KJob *job)
     case Result_AutoSkip:
         m_bAutoSkipFiles = true;
     // fall through
+        Q_FALLTHROUGH();
     case Result_Skip:
         // Move on to next file
         skip((*it).uSource, false);
@@ -1502,7 +1508,7 @@ void CopyJobPrivate::slotResultErrorCopyingFiles(KJob *job)
         // Do nothing, copy file again
         break;
     default:
-        assert(0);
+        Q_ASSERT(0);
     }
     state = STATE_COPYING_FILES;
     copyNextFile();
@@ -1840,7 +1846,7 @@ void CopyJobPrivate::slotResultDeletingDirs(KJob *job)
         m_successSrcList.append(static_cast<KIO::SimpleJob *>(job)->url());
     }
     q->removeSubjob(job);
-    assert(!q->hasSubjobs());
+    Q_ASSERT(!q->hasSubjobs());
     deleteNextDir();
 }
 
@@ -1853,7 +1859,7 @@ void CopyJobPrivate::slotResultSettingDirAttributes(KJob *job)
         // Let's not display warnings for each dir like "cp -a" does.
     }
     q->removeSubjob(job);
-    assert(!q->hasSubjobs());
+    Q_ASSERT(!q->hasSubjobs());
     setNextDirAttribute();
 }
 
@@ -1868,7 +1874,7 @@ void CopyJobPrivate::slotResultRenaming(KJob *job)
     Q_ASSERT(kiojob);
     m_incomingMetaData += kiojob->metaData();
     q->removeSubjob(job);
-    assert(!q->hasSubjobs());
+    Q_ASSERT(!q->hasSubjobs());
     // Determine dest again
     QUrl dest = m_dest;
     if (destinationState == DEST_IS_DIR && !m_asMethod) {
@@ -2030,6 +2036,7 @@ void CopyJobPrivate::slotResultRenaming(KJob *job)
                         m_bAutoRenameFiles = true;
                     }
                 // fall through
+                    Q_FALLTHROUGH();
                 case Result_Rename: {
                     // Set m_dest to the chosen destination
                     // This is only for this src url; the next one will revert to m_globalDest
@@ -2047,6 +2054,7 @@ void CopyJobPrivate::slotResultRenaming(KJob *job)
                         m_bAutoSkipFiles = true;
                     }
                 // fall through
+                    Q_FALLTHROUGH();
                 case Result_Skip:
                     // Move on to next url
                     skipSrc(isDir);
@@ -2068,7 +2076,7 @@ void CopyJobPrivate::slotResultRenaming(KJob *job)
                     m_overwriteList.insert(dest.path());
                     break;
                 default:
-                    //assert( 0 );
+                    //Q_ASSERT( 0 );
                     break;
                 }
             } else if (err != KIO::ERR_UNSUPPORTED_ACTION) {
@@ -2126,7 +2134,7 @@ void CopyJob::slotResult(KJob *job)
         }
 
         removeSubjob(job);
-        assert(!hasSubjobs());
+        Q_ASSERT(!hasSubjobs());
 
         d->statNextSrc();
         break;
@@ -2149,7 +2157,7 @@ void CopyJob::slotResult(KJob *job)
         d->slotResultSettingDirAttributes(job);
         break;
     default:
-        assert(0);
+        Q_ASSERT(0);
     }
 }
 
