@@ -103,7 +103,7 @@ KIOCORE_EXPORT QString KIO::buildErrorString(int errorCode, const QString &error
         result = i18n("Could not create socket for accessing %1.",  errorText);
         break;
     case  KIO::ERR_CANNOT_CONNECT:
-        result = i18n("Could not connect to host %1.",  errorText.isEmpty() ? QLatin1String("localhost") : errorText);
+        result = i18n("Could not connect to host %1.",  errorText.isEmpty() ? QStringLiteral("localhost") : errorText);
         break;
     case  KIO::ERR_CONNECTION_BROKEN:
         result = i18n("Connection to host %1 is broken.",  errorText);
@@ -216,7 +216,7 @@ KIOCORE_EXPORT QString KIO::buildErrorString(int errorCode, const QString &error
         result = errorText;
         break;
     case KIO::ERR_DISK_FULL:
-        result = i18n("Could not write file %1.\nDisk full.",  errorText);
+        result = i18n("There is not enough space on the disk to write %1.",  errorText);
         break;
     case KIO::ERR_IDENTICAL_FILES:
         result = i18n("The source and destination are the same file.\n%1",  errorText);
@@ -239,8 +239,14 @@ KIOCORE_EXPORT QString KIO::buildErrorString(int errorCode, const QString &error
     case KIO::ERR_CANNOT_MOVE_INTO_ITSELF:
         result = i18n("A folder cannot be moved into itself");
         break;
+    case KIO::ERR_PASSWD_SERVER:
+        result = i18n("Communication with the local password server failed");
+        break;
+    case KIO::ERR_CANNOT_CREATE_SLAVE:
+        result = i18n("Unable to create io-slave. %1", errorText);
+        break;
     default:
-        result = i18n("Unknown error code %1\n%2\nPlease send a full bug report at http://bugs.kde.org.",  errorCode,  errorText);
+        result = i18n("Unknown error code %1\n%2\nPlease send a full bug report at https://bugs.kde.org.",  errorCode,  errorText);
         break;
     }
 
@@ -375,7 +381,6 @@ KIOCORE_EXPORT QByteArray KIO::rawErrorDetail(int errorCode, const QString &erro
     QString cProtocol = i18n("A protocol error or incompatibility may have occurred.");
     QString sExists = i18n("Ensure that the resource exists, and try again.");
     QString cExists = i18n("The specified resource may not exist.");
-    QString cTypo = i18n("You may have incorrectly typed the location.");
     QString sTypo = i18n("Double-check that you have entered the correct location "
                          "and try again.");
     QString sNetwork = i18n("Check your network connection status.");
@@ -401,10 +406,10 @@ KIOCORE_EXPORT QByteArray KIO::rawErrorDetail(int errorCode, const QString &erro
         break;
 
     case  KIO::ERR_CANNOT_LAUNCH_PROCESS:
-        errorName = i18n("Cannot Initiate the %1 Protocol",  protocol);
+        errorName = i18n("Cannot Launch Process required by the %1 Protocol",  protocol);
         techName = i18n("Unable to Launch Process");
         description = i18n("The program on your computer which provides access "
-                           "to the <strong>%1</strong> protocol could not be started. This is "
+                           "to the <strong>%1</strong> protocol could not be found or started. This is "
                            "usually due to technical reasons.",  protocol);
         causes << i18n("The program which provides compatibility with this "
                        "protocol may not have been updated with your last update of KDE. "
@@ -1045,6 +1050,24 @@ KIOCORE_EXPORT QByteArray KIO::rawErrorDetail(int errorCode, const QString &erro
         solutions << i18n("Move the item into a different folder.");
         break;
 
+    case KIO::ERR_PASSWD_SERVER:
+        errorName = i18n("Could not communicate with password server");
+        description = i18n("The operation could not be completed because the "
+                           "service for requesting passwords (kpasswdserver) couldn't be contacted");
+        solutions << i18n("Try restarting your session, or look in the logs for errors from kiod.");
+        break;
+
+    case KIO::ERR_CANNOT_CREATE_SLAVE:
+        errorName = i18n("Cannot Initiate the %1 Protocol",  protocol);
+        techName = i18n("Unable to Create io-slave");
+        description = i18n("The io-slave which provides access "
+                           "to the <strong>%1</strong> protocol could not be started. This is "
+                           "usually due to technical reasons.",  protocol);
+        causes << i18n("klauncher could not find or start the plugin which provides the protocol."
+                       "This means you may have an outdated version of the plugin.");
+        solutions << sUpdate << sSysadmin;
+        break;
+
     default:
         // fall back to the plain error...
         errorName = i18n("Undocumented Error");
@@ -1059,7 +1082,7 @@ KIOCORE_EXPORT QByteArray KIO::rawErrorDetail(int errorCode, const QString &erro
 
 QFile::Permissions KIO::convertPermissions(int permissions)
 {
-    QFile::Permissions qPermissions(0);
+    QFile::Permissions qPermissions;
 
     if (permissions > 0) {
         if (permissions & S_IRUSR) {
