@@ -306,7 +306,7 @@ int SimpleJobPrivate::requestMessageBox(int _type, const QString &text, const QS
         return m_uiDelegateExtension->requestMessageBox(type, text, caption, buttonYes, buttonNo,
                 iconYes, iconNo, dontAskAgainName, sslMetaData);
     }
-    qCWarning(KIO_CORE) << "JobUiDelegate not set! Returing -1";
+    qCWarning(KIO_CORE) << "JobUiDelegate not set! Returning -1";
     return -1;
 }
 
@@ -338,7 +338,7 @@ void SimpleJob::storeSSLSessionFromJob(const QUrl &redirectionURL)
 
 void SimpleJobPrivate::slotPrivilegeOperationRequested()
 {
-    m_slave->send(MSG_PRIVILEGE_EXEC, QByteArray::number(tryAskPrivilegeOpConfirmation()));
+    m_slave->send(MSG_PRIVILEGE_EXEC, privilegeOperationData());
 }
 
 //////////
