@@ -24,10 +24,7 @@
 #include "connection_p.h"
 #include "commands_p.h"
 #include "hostinfo.h"
-#include <errno.h>
-#include <stdlib.h>
-#include <sys/time.h>
-#include <unistd.h>
+#include <qplatformdefs.h>
 #include <signal.h>
 #include <klocalizedstring.h>
 #include <time.h>
@@ -35,9 +32,10 @@
 #include <QDebug>
 
 #include <QDBusConnection>
-#include <QtCore/QPointer>
-#include <QtNetwork/QSslCertificate>
-#include <QtNetwork/QSslError>
+#include <QPointer>
+#include <QDataStream>
+#include <QSslCertificate>
+#include <QSslError>
 
 using namespace KIO;
 
@@ -99,11 +97,8 @@ void SlaveInterface::calcSpeed()
         return;
     }
 
-    struct timeval tv;
-    gettimeofday(&tv, 0);
-
-    long diff = ((tv.tv_sec - d->start_time.tv_sec) * 1000000 +
-                 tv.tv_usec - d->start_time.tv_usec) / 1000;
+    const qint64 currentTime = QDateTime::currentMSecsSinceEpoch();
+    const qint64 diff = currentTime - d->start_time;
     if (diff - d->last_time >= 900) {
         d->last_time = diff;
         if (d->nums == max_nums) {
@@ -136,20 +131,6 @@ void SlaveInterface::calcSpeed()
     }
 }
 
-/*
- * Map pid_t to a signed integer type that makes sense for QByteArray;
- * only the most common sizes 16 bit and 32 bit are special-cased.
- */
-template<int T> struct PIDType {
-    typedef pid_t PID_t;
-};
-template<> struct PIDType<2> {
-    typedef qint16 PID_t;
-};
-template<> struct PIDType<4> {
-    typedef qint32 PID_t;
-};
-
 bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
 {
     Q_D(SlaveInterface);
@@ -185,15 +166,14 @@ bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
         break;
     }
     case MSG_LIST_ENTRIES: {
-        quint32 count;
-        stream >> count;
-
         UDSEntryList list;
         UDSEntry entry;
-        for (uint i = 0; i < count; i++) {
+
+        while (!stream.atEnd()) {
             stream >> entry;
             list.append(entry);
         }
+
         emit listEntries(list);
         break;
     }
@@ -211,12 +191,11 @@ bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
         //qDebug() << "error " << i << " " << str1;
         emit error(i, str1);
         break;
-    case MSG_SLAVE_STATUS: {
-        PIDType<sizeof(pid_t)>::PID_t stream_pid;
-        pid_t pid;
+    case MSG_SLAVE_STATUS:
+    case MSG_SLAVE_STATUS_V2: {
+        qint64 pid;
         QByteArray protocol;
-        stream >> stream_pid >> protocol >> str1 >> b;
-        pid = stream_pid;
+        stream >> pid >> protocol >> str1 >> b;
         emit slaveStatus(pid, protocol, str1, (b != 0));
         break;
     }
@@ -230,7 +209,7 @@ bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
     }
     case INF_TOTAL_SIZE: {
         KIO::filesize_t size = readFilesize_t(stream);
-        gettimeofday(&d->start_time, 0);
+        d->start_time = QDateTime::currentMSecsSinceEpoch();
         d->last_time = 0;
         d->filesize = d->offset;
         d->sizes[0] = d->filesize - d->offset;
@@ -302,7 +281,7 @@ bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
     case INF_META_DATA: {
         MetaData m;
         stream >> m;
-        if (m.contains(QLatin1String("ssl_in_use"))) {
+        if (m.contains(QStringLiteral("ssl_in_use"))) {
             const QLatin1String ssl_("ssl_");
             const MetaData constM = m;
             for (MetaData::ConstIterator it = constM.lowerBound(ssl_); it != constM.constEnd(); ++it) {
@@ -341,8 +320,11 @@ bool SlaveInterface::dispatch(int _cmd, const QByteArray &rawdata)
         HostInfo::lookupHost(hostName, this, SLOT(slotHostInfo(QHostInfo)));
         break;
     }
+    case MSG_PRIVILEGE_EXEC:
+        emit privilegeOperationRequested();
+        break;
     default:
-        qWarning() << "Slave sends unknown command (" << _cmd << "), dropping slave";
+        qCWarning(KIO_CORE) << "Slave sends unknown command (" << _cmd << "), dropping slave";
         return false;
     }
     return true;
