@@ -93,7 +93,7 @@ public:
     /**
      * Destructor
      */
-    virtual ~KFileWidget();
+    ~KFileWidget() override;
 
     /**
      * Defines some default behavior of the filedialog.
@@ -458,7 +458,7 @@ public:
 
     /**
      * Sets whether the user should be asked for confirmation
-     * when an overwrite might occurr.
+     * when an overwrite might occur.
      *
      * @param enable Set this to true to enable checking.
      * @since 4.2
@@ -492,7 +492,28 @@ public:
     /**
      * Reimplemented
      */
-    QSize sizeHint() const Q_DECL_OVERRIDE;
+    QSize sizeHint() const override;
+
+    /**
+     * Set the URL schemes that the file widget should allow navigating to.
+     *
+     * If the returned list is empty, all schemes are supported.
+     *
+     * @sa QFileDialog::setSupportedSchemes
+     * @since 5.43
+     */
+    void setSupportedSchemes(const QStringList &schemes);
+
+    /**
+     * Returns the URL schemes that the file widget should allow navigating to.
+     *
+     * If the returned list is empty, all schemes are supported. Examples for
+     * schemes are @c "file" or @c "ftp".
+     *
+     * @sa QFileDialog::supportedSchemes
+     * @since 5.43
+     */
+    QStringList supportedSchemes() const;
 
 public Q_SLOTS:
     /**
@@ -504,9 +525,9 @@ public Q_SLOTS:
     void slotCancel();
 
 protected:
-    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
-    void showEvent(QShowEvent *event) Q_DECL_OVERRIDE;
-    bool eventFilter(QObject *watched, QEvent *event) Q_DECL_OVERRIDE;
+    void resizeEvent(QResizeEvent *event) override;
+    void showEvent(QShowEvent *event) override;
+    bool eventFilter(QObject *watched, QEvent *event) override;
 
 Q_SIGNALS:
     /**
@@ -591,6 +612,7 @@ private:
     Q_PRIVATE_SLOT(d, void _k_zoomInIconsSize())
     Q_PRIVATE_SLOT(d, void _k_slotIconSizeSliderMoved(int))
     Q_PRIVATE_SLOT(d, void _k_slotIconSizeChanged(int))
+    Q_PRIVATE_SLOT(d, void _k_slotViewDoubleClicked(const QModelIndex&))
 };
 
 #endif
