@@ -6,7 +6,7 @@
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later versio
+   version 2 of the License, or (at your option) any later version
 
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -22,20 +22,21 @@
 #include <config-help.h>
 
 #include "kio_help.h"
-#include "xslt.h"
 #include "xslt_help.h"
 
+#include <docbookxslt.h>
+
 #include <KLocalizedString>
 
 #include <QDebug>
 
-#include <QtCore/QDir>
-#include <QtCore/QFileInfo>
-#include <QtCore/QFile>
-#include <QtCore/QLocale>
+#include <QDir>
+#include <QFileInfo>
+#include <QFile>
+#include <QLocale>
 #include <QMimeDatabase>
-#include <QtCore/QRegExp>
-#include <QtCore/QTextCodec>
+#include <QRegExp>
+#include <QTextCodec>
 #include <QStandardPaths>
 #include <QTextDocument>
 #include <QUrl>
@@ -50,7 +51,7 @@ QString HelpProtocol::langLookup(const QString &fname)
     QStringList search;
 
     // assemble the local search paths
-    const QStringList localDoc = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("doc/HTML"), QStandardPaths::LocateDirectory);
+    const QStringList localDoc = KDocTools::documentationDirs();
 
     QStringList langs = KLocalizedString::languages();
     langs.append(QStringLiteral("en"));
@@ -122,7 +123,7 @@ QString HelpProtocol::lookupFile(const QString &fname,
                 redirection(red);
                 redirect = true;
             } else {
-                unicodeError(i18n("There is no documentation available for %1.", path.toHtmlEscaped()));
+                sendError(i18n("There is no documentation available for %1.", path.toHtmlEscaped()));
                 return QString();
             }
         }
@@ -133,15 +134,10 @@ QString HelpProtocol::lookupFile(const QString &fname,
     return result;
 }
 
-void HelpProtocol::unicodeError(const QString &t)
+void HelpProtocol::sendError(const QString &t)
 {
-#ifdef Q_OS_WIN
-    QString encoding = "UTF-8";
-#else
-    QString encoding = QTextCodec::codecForLocale()->name();
-#endif
-    data(fromUnicode(QStringLiteral(
-                         "<html><head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=%1\"></head>\n%2</html>").arg(encoding, t.toHtmlEscaped())));
+    data(QStringLiteral(
+         "<html><head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"></head>\n%1</html>").arg(t.toHtmlEscaped()).toUtf8());
 
 }
 
@@ -230,12 +226,12 @@ void HelpProtocol::get(const QUrl &url)
 
     if (mGhelp) {
         QString xsl = QStringLiteral("customization/kde-nochunk.xsl");
-        mParsed = transform(file, locateFileInDtdResource(xsl));
+        mParsed = KDocTools::transform(file, KDocTools::locateFileInDtdResource(xsl));
 
         //qDebug() << "parsed " << mParsed.length();
 
         if (mParsed.isEmpty()) {
-            unicodeError(i18n("The requested help file could not be parsed:<br />%1",  file));
+            sendError(i18n("The requested help file could not be parsed:<br />%1",  file));
         } else {
             int pos1 = mParsed.indexOf(QStringLiteral("charset="));
             if (pos1 > 0) {
@@ -255,7 +251,7 @@ void HelpProtocol::get(const QUrl &url)
         //qDebug() << "cached parsed " << mParsed.length();
 
         if (mParsed.isEmpty()) {
-            mParsed = transform(file, locateFileInDtdResource(QStringLiteral("customization/kde-chunk.xsl")));
+            mParsed = KDocTools::transform(file, KDocTools::locateFileInDtdResource(QStringLiteral("customization/kde-chunk.xsl")));
             if (!mParsed.isEmpty()) {
                 infoMessage(i18n("Saving to cache"));
 #ifdef Q_OS_WIN
@@ -264,14 +260,14 @@ void HelpProtocol::get(const QUrl &url)
                 // accessing user data from another location invalids cached files
                 // Accessing user data under a different path is possible
                 // when using usb sticks - this may affect unix/mac systems also
-                const QString installPath = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, "doc/HTML", QStandardPaths::LocateDirectory).last();
+                const QString installPath = KDocTools::documentationDirs().last();
 
                 QString cache = '/' + fi.absolutePath().remove(installPath, Qt::CaseInsensitive).replace('/', '_') + '_' + fi.baseName() + '.';
 #else
                 QString cache = file.left(file.length() - 7);
 #endif
-                saveToCache(mParsed, QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation)
-                            + "/kio_help" + cache + "cache.bz2");
+                KDocTools::saveToCache(mParsed, QStandardPaths::writableLocation(QStandardPaths::GenericCacheLocation)
+                                       + "/kio_help" + cache + "cache.bz2");
             }
         } else {
             infoMessage(i18n("Using cached version"));
@@ -280,7 +276,7 @@ void HelpProtocol::get(const QUrl &url)
         //qDebug() << "parsed " << mParsed.length();
 
         if (mParsed.isEmpty()) {
-            unicodeError(i18n("The requested help file could not be parsed:<br />%1",  file));
+            sendError(i18n("The requested help file could not be parsed:<br />%1",  file));
         } else {
             QString anchor;
             QString query = url.query();
@@ -340,21 +336,13 @@ void HelpProtocol::emitFile(const QUrl &url)
 
     QString filename = url.path().mid(url.path().lastIndexOf('/') + 1);
 
-    int index = mParsed.indexOf(QStringLiteral("<FILENAME filename=\"%1\"").arg(filename));
-    if (index == -1) {
-        if (filename == QLatin1String("index.html")) {
-            data(fromUnicode(mParsed));
-            return;
-        }
+    QByteArray result = KDocTools::extractFileToBuffer(mParsed, filename);
 
-        unicodeError(i18n("Could not find filename %1 in %2.", filename, url.toString()));
-        return;
+    if (result.isNull()) {
+        sendError(i18n("Could not find filename %1 in %2.", filename, url.toString()));
+    } else {
+        data(result);
     }
-
-    QString filedata = splitOut(mParsed, index);
-    replaceCharsetHeader(filedata);
-
-    data(fromUnicode(filedata));
     data(QByteArray());
 }
 
