@@ -28,8 +28,8 @@
 #include <QApplication>
 #include <QDesktopWidget>
 #include <QDialogButtonBox>
-#include <QtCore/QtAlgorithms>
-#include <QtCore/QList>
+#include <QtAlgorithms>
+#include <QList>
 #include <QKeyEvent>
 #include <QLabel>
 #include <QLayout>
@@ -395,7 +395,7 @@ bool QTreeViewProxyFilter::filterAcceptsRow(int sourceRow, const QModelIndex &pa
         return true;
     }
 
-    //Show the non-leaf node also if the regexp matches one one of its children
+    //Show the non-leaf node also if the regexp matches one of its children
     int rows = sourceModel()->rowCount(index);
     for (int crow = 0; crow < rows; crow++) {
         if (filterAcceptsRow(crow, index)) {
@@ -661,7 +661,7 @@ void KOpenWithDialogPrivate::init(const QString &_text, const QString &_value)
         KHistoryComboBox *combo = new KHistoryComboBox();
         combo->setToolTip(i18n("Type to filter the applications below, or specify the name of a command.\nPress down arrow to navigate the results."));
         KLineEdit *lineEdit = new KLineEdit(q);
-        lineEdit->setClearButtonShown(true);
+        lineEdit->setClearButtonEnabled(true);
         combo->setLineEdit(lineEdit);
         combo->setSizeAdjustPolicy(QComboBox::AdjustToMinimumContentsLengthWithIcon);
         combo->setDuplicatesEnabled(false);
